# encoding: utf-8

from __future__ import absolute_import

import cn2an.version as version
import cn2an.cn2an as cn2an
import cn2an.an2cn as an2cn


__version__ = version.VERSION
cn2an = cn2an.Cn2An().cn2an
an2cn = an2cn.An2Cn().an2cn


# encoding: utf-8
import codecs

import yaml

def get_default_conf():
    with codecs.open("./cn2an/config.yaml", "r", encoding="utf-8") as f_config:
        config_data = yaml.load(f_config)
    return config_data
 